package Tickit::Widget::Statusbar::WidgetList;
$Tickit::Widget::Statusbar::WidgetList::VERSION = '0.004';
use strict;
use warnings;

=head1 NAME

Tickit::Widget::Statusbar::WidgetList

=head1 VERSION

version 0.004

=head1 SYNOPSIS

=head1 DESCRIPTION

Provides a statusbar item which will show a popup list of
widgets when activated. Typically used for restoring
"minimised" items.

=cut

=head1 METHODS

=cut

1;

__END__

=head1 AUTHOR

Tom Molesworth <cpan@perlsite.co.uk>

=head1 LICENSE

Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
